# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - IncludeComments Macro

    @copyright: 2013 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMoin.action import ActionBase
from MoinMoin.PageEditor import PageEditor
from MoinMoin.wikiutil import escape
from MoinSupport import getPagesForSearch, getPagesFromResults, ActionSupport

Dependencies = ['pages']

class PostComment(ActionBase, ActionSupport):

    "Post a comment to the wiki."

    def get_form_html(self, buttons_html):

        "Return the action's form incorporating the 'buttons_html'."

        _ = self._
        request = self.request
        form = self.get_form()

        comment = form.get("comment", [""])[0]

        d = {
            "comment_label"     : escape(_("Write a comment in the box.")),
            "comment_default"   : escape(comment),
            "buttons_html"      : buttons_html,
            }

        return u"""\
<p>%(comment_label)s</p>
<textarea name="comment" cols="60" rows="10">%(comment_default)s</textarea>
<p>%(buttons_html)s</p>
""" % d

    def do_action(self):

        "Attempt to post a comment."

        _ = self._
        request = self.request
        form = self.get_form()

        comment = form.get("comment", [""])[0]

        if not comment.strip():
            return 0, _("A comment should have some content.")

        if not request.user.valid or not request.user.may.write(self.pagename):
            return 0, _("You are not allowed to comment on this page.")

        # Determine the last comment.

        comments = get_comment_numbers(self.pagename, request)
        last_comment_pagename = comments and comments[-1] or -1

        # Write the new page.

        new_page = PageEditor(request, "%s/%04d" % (self.pagename, last_comment_pagename + 1))

        try:
            new_page.saveText(comment, 0)
            return 1, _("Comment added.")
        except new_page.SaveError, exc:
            return 0, unicode(exc)

def get_comment_numbers(pagename, request):

    """
    Return a list of comment numbers associated with the given 'pagename', using
    the 'request' provided.
    """

    pagenames = []

    for page in getPagesForSearch("title:regex:^%s/" % pagename, request):
        basename, number = page.page_name.rsplit("/", 1)
        if basename == pagename and number.isdigit():
            pagenames.append(int(number))

    pagenames.sort()
    return pagenames

# Action invocation function.

def execute(pagename, request):
    PostComment(pagename, request).render()

# vim: tabstop=4 expandtab shiftwidth=4
